# Open R console
# Set working directory
setwd(...)

# make sure downloaded text file "V9_data_for_figure.txt" is stored in the working directory. 

# Read the content of text file
dataForPaper = read.table("V9_data_for_figure.txt", sep=",", h=T)

  taxo_datab   = dataForPaper[dataForPaper$Depth=="SUR",]
  taxo_datab   = taxo_datab[order(taxo_datab$Station),]
  taxo_datab_d = dataForPaper[dataForPaper$Depth=="DCM",]
  taxo_datab_d = taxo_datab_d[order(taxo_datab_d$Station),]

      
library("rworldmap")
my.colors   = colorRampPalette(c("#0072B2", "#D55E00"))

#------------------------------------------------------------------------------#
# Figure 7a-b-c-d                                                              #
# Biogeographical distributions of Minidiscus from metabarcoding data          #
#------------------------------------------------------------------------------#
      df1=data.frame(long=taxo_datab$Longitude,
                     lat=taxo_datab$Latitude,
                     abun=round(taxo_datab$Minidiscus_rel_diatom,5),
                     expH=round(exp(taxo_datab$Minidiscus_shannon),1))
      tempRange = data.frame(long=c(280,280),lat=c(80,90),abun=c(0,52),expH=c(1,7))
      df1 = rbind(df1,tempRange)
      sizeval=colnames(df1)[3]
      colval= colnames(df1)[4]

      df2=data.frame(long=taxo_datab$Longitude,
                     lat=taxo_datab$Latitude,
                     abun=round(taxo_datab$Minidiscus_rel_photo,5),
                     expH=round(exp(taxo_datab$Minidiscus_shannon),1))
      tempRange2 = data.frame(long=c(280,280),lat=c(80,90),abun=c(0,4),expH=c(1,7))
      df2 = rbind(df2,tempRange2)
      sizeval2=colnames(df2)[3]
      colval2= colnames(df2)[4]

      df3=data.frame(long=taxo_datab_d$Longitude,
                     lat=taxo_datab_d$Latitude,
                     abun=round(taxo_datab_d$Minidiscus_rel_diatom,5),
                     expH=round(exp(taxo_datab_d$Minidiscus_shannon),1))
      tempRange3 = data.frame(long=c(280,280),lat=c(80,90),abun=c(0,52),expH=c(1,7))
      df3 = rbind(df3,tempRange3)
      sizeval3=colnames(df3)[3]
      colval3= colnames(df3)[4]

      df4=data.frame(long=taxo_datab_d$Longitude,
                     lat=taxo_datab_d$Latitude,
                     abun=round(taxo_datab_d$Minidiscus_rel_photo,5),
                     expH=round(exp(taxo_datab_d$Minidiscus_shannon),1))
      tempRange4 = data.frame(long=c(280,280),lat=c(80,90),abun=c(0,4),expH=c(1,7))
      df4 = rbind(df4,tempRange4)
      sizeval4=colnames(df4)[3]
      colval4= colnames(df4)[4]


      dev.new(height=6, width=9)
      par(mar=c(0.5,0.5,0.5,0.5), mfrow=c(2,2), oma=c(0,0,2,0))
      mapBubbles(df1, nameX="long", nameY="lat", mapRegion="world",
                    nameZSize=sizeval, nameZColour=colval, fill=TRUE, pch=21, numCats=6 , bg="black",
                    catMethod="categorial", colourPalette = my.colors(6), symbolSize = 1,
                    addLegend =TRUE, legendPos = "bottomleft", legendTitle = "RelAbun(%)",legendVals= round(range(df1[,3],na.rm=TRUE),1),
                    addColourLegend = TRUE, colourLegendPos = "bottomright",colourLegendTitle = "expH", colourLegendVals = round(range(df1[,4],na.rm=TRUE),0),
                    oceanCol = "white", landCol ="lightyellow3", borderCol=NA)
      mtext("a. Surface | 0.8-5", side=3, adj=0.05, line=-2, cex=0.9, font=2)
      mtext("*Relative abundance w.r.t. total diatom reads", side=1, line=-2.5, cex=0.5, font=1)
      mtext("Minidiscus", side=3,  line=-0.5, cex=1.5, font=2, outer=T)

      mapBubbles(df2, nameX="long", nameY="lat", mapRegion="world",
                    nameZSize=sizeval2, nameZColour=colval2, fill=TRUE, pch=21, numCats=6 , bg="black",
                    catMethod="categorial", colourPalette = my.colors(6), symbolSize = 1,
                    addLegend =TRUE, legendPos = "bottomleft", legendTitle = "RelAbun(%)",legendVals =round(range(df2[,3],na.rm=TRUE),1),
                    addColourLegend = TRUE, colourLegendPos = "bottomright",colourLegendTitle = "expH", colourLegendVals = round(range(df2[,4],na.rm=TRUE),0),
                    oceanCol = "white", landCol ="lightyellow3", borderCol=NA)
      mtext("b. Surface | 0.8-5", side=3, adj=0.05, line=-2, cex=0.9, font=2)
      mtext("*Relative abundance w.r.t. total phytoplankton reads", side=1, line=-2.5, cex=0.5, font=1)
      
      mapBubbles(df3, nameX="long", nameY="lat", mapRegion="world",
                    nameZSize=sizeval3, nameZColour=colval3, fill=TRUE, pch=21, numCats=6 , bg="black",
                    catMethod="categorial", colourPalette = my.colors(6), symbolSize = 1,
                    addLegend =TRUE, legendPos = "bottomleft", legendTitle = "RelAbun(%)",legendVals =round(range(df3[,3],na.rm=TRUE),1),
                    addColourLegend = TRUE, colourLegendPos = "bottomright",colourLegendTitle = "expH", colourLegendVals = round(range(df3[,4],na.rm=TRUE),0),
                    oceanCol = "white", landCol ="lightyellow3", borderCol=NA)
      mtext("c. Deep Chlorophyll Maximum | 0.8-5", side=3, adj=0.05, line=-2, cex=0.9, font=2)
      mtext("*Relative abundance w.r.t. total diatom reads", side=1, line=-2.5, cex=0.5, font=1)
      
      mapBubbles(df4, nameX="long", nameY="lat", mapRegion="world",
                    nameZSize=sizeval4, nameZColour=colval4, fill=TRUE, pch=21, numCats=6 , bg="black",
                    catMethod="categorial", colourPalette = my.colors(6), symbolSize = 1,
                    addLegend =TRUE, legendPos = "bottomleft", legendTitle = "RelAbun(%)",legendVals =round(range(df4[,3],na.rm=TRUE),1),
                    addColourLegend = TRUE, colourLegendPos = "bottomright",colourLegendTitle = "expH", colourLegendVals = round(range(df4[,4],na.rm=TRUE),0),
                    oceanCol = "white", landCol ="lightyellow3", borderCol=NA)
      mtext("d. Deep Chlorophyll Maximum | 0.8-5", side=3, adj=0.05, line=-2, cex=0.9, font=2)
      mtext("*Relative abundance w.r.t. total phytoplankton reads", side=1, line=-2.5, cex=0.5, font=1)
      
      
#------------------------------------------------------------------------------#
# Supplementary figure 5a-b-c-d                                                #
# Biogeographical distributions of Minutocellus from metabarcoding data        #
#------------------------------------------------------------------------------#
      df5=data.frame(long=taxo_datab$Longitude,
                   lat=taxo_datab$Latitude,
                   abun=round(taxo_datab$Minutocellus_rel_diatom,5),
                   expH=round(exp(taxo_datab$Minutocellus_shannon),1))
      tempRange5 = data.frame(long=c(280,280),lat=c(80,90),abun=c(0,14),expH=c(1,8))
      df5 = rbind(df5,tempRange5)
      sizeval5=colnames(df5)[3]
      colval5= colnames(df5)[4]

      df6=data.frame(long=taxo_datab$Longitude,
                     lat=taxo_datab$Latitude,
                     abun=round(taxo_datab$Minutocellus_rel_photo,5),
                     expH=round(exp(taxo_datab$Minutocellus_shannon),1))
      tempRange6 = data.frame(long=c(280,280),lat=c(80,90),abun=c(0,2),expH=c(1,8))
      df6 = rbind(df6,tempRange6)
      sizeval6=colnames(df6)[3]
      colval6= colnames(df6)[4]

      df7=data.frame(long=taxo_datab_d$Longitude,
                     lat=taxo_datab_d$Latitude,
                     abun=round(taxo_datab_d$Minutocellus_rel_diatom,5),
                     expH=round(exp(taxo_datab_d$Minutocellus_shannon),1))
      tempRange7 = data.frame(long=c(280,280),lat=c(80,90),abun=c(0,14),expH=c(1,8))
      df7 = rbind(df7,tempRange7)
      sizeval7=colnames(df7)[3]
      colval7= colnames(df7)[4]

      df8=data.frame(long=taxo_datab_d$Longitude,
                     lat=taxo_datab_d$Latitude,
                     abun=round(taxo_datab_d$Minutocellus_rel_photo,5),
                     expH=round(exp(taxo_datab_d$Minutocellus_shannon),1))
      tempRange8 = data.frame(long=c(280,280),lat=c(80,90),abun=c(0,2),expH=c(1,8))
      df8 = rbind(df8,tempRange8)
      sizeval8=colnames(df8)[3]
      colval8= colnames(df8)[4]

                                       
      dev.new(height=6, width=9)
      par(mar=c(0.5,0.5,0.5,0.5), mfrow=c(2,2), oma=c(0,0,2,0), family="sans")
       
      mapBubbles(df5, nameX="long", nameY="lat", mapRegion="world",
                    nameZSize=sizeval5, nameZColour=colval5, fill=TRUE, pch=21, numCats=7 , bg="black",
                    catMethod="categorial", colourPalette = my.colors(7), symbolSize = 1,
                    addLegend =TRUE, legendPos = "bottomleft", legendTitle = "RelAbun(%)",legendVals =round(range(df5[,3],na.rm=TRUE),1),
                    addColourLegend = TRUE, colourLegendPos = "bottomright",colourLegendTitle = "expH", colourLegendVals = round(range(df5[,4],na.rm=TRUE),0),
                    oceanCol = "white", landCol ="lightyellow3", borderCol=NA)
      mtext("a. Surface | 0.8-5", side=3, adj=0.05, line=-2, cex=0.9, font=2)
      mtext("*Relative abundance w.r.t. total diatom reads", side=1, line=-2.5, cex=0.5, font=1)
      mtext("Minutocellus", side=3, line=-0.5, cex=1.5, font=2, outer=T)
   
      mapBubbles(df6, nameX="long", nameY="lat", mapRegion="world",
                    nameZSize=sizeval6, nameZColour=colval6, fill=TRUE, pch=21, numCats=7 , bg="black",
                    catMethod="categorial", colourPalette = my.colors(7), symbolSize = 1,
                    addLegend =TRUE, legendPos = "bottomleft", legendTitle = "RelAbun(%)",legendVals =round(range(df6[,3],na.rm=TRUE),1),
                    addColourLegend = TRUE, colourLegendPos = "bottomright",colourLegendTitle = "expH", colourLegendVals = round(range(df6[,4],na.rm=TRUE),0),
                    oceanCol = "white", landCol ="lightyellow3", borderCol=NA)
      mtext("b. Surface | 0.8-5", side=3, adj=0.05, line=-2, cex=0.9, font=2)
      mtext("*Relative abundance w.r.t. total phytoplankton reads", side=1, line=-2.5, cex=0.5, font=1)
      
     mapBubbles(df7, nameX="long", nameY="lat", mapRegion="world",
                    nameZSize=sizeval7, nameZColour=colval7, fill=TRUE, pch=21, numCats=7 , bg="black",
                    catMethod="categorial", colourPalette = my.colors(7), symbolSize = 1,
                    addLegend =TRUE, legendPos = "bottomleft", legendTitle = "RelAbun(%)",legendVals =round(range(df7[,3],na.rm=TRUE),1),
                    addColourLegend = TRUE, colourLegendPos = "bottomright",colourLegendTitle = "expH",colourLegendVals = round(range(df7[,4],na.rm=TRUE),0),
                    oceanCol = "white", landCol ="lightyellow3", borderCol=NA)
      mtext("c. Deep Chlorophyll Maximum | 0.8-5", side=3, adj=0.05, line=-2, cex=0.9, font=2)
      mtext("*Relative abundance w.r.t. total diatom reads", side=1, line=-2.5, cex=0.5, font=1)
     
      mapBubbles(df8, nameX="long", nameY="lat", mapRegion="world",
                    nameZSize=sizeval8, nameZColour=colval8, fill=TRUE, pch=21, numCats=7 , bg="black",
                    catMethod="categorial", colourPalette = my.colors(7), symbolSize = 1,
                    addLegend =TRUE, legendPos = "bottomleft", legendTitle = "RelAbun(%)",legendVals =round(range(df8[,3],na.rm=TRUE),1),
                    addColourLegend = TRUE, colourLegendPos = "bottomright",colourLegendTitle = "expH", colourLegendVals = round(range(df8[,4],na.rm=TRUE),0),
                    oceanCol = "white", landCol ="lightyellow3", borderCol=NA)
      mtext("d. Deep Chlorophyll Maximum | 0.8-5", side=3, adj=0.05, line=-2, cex=0.9, font=2)
      mtext("*Relative abundance w.r.t. total phytoplankton reads", side=1, line=-2.5, cex=0.5, font=1)
      
     







